BnSpot

Struct BnSpot 

pub struct BnSpot { /* private fields */ }

Implementations

Source

impl BnSpot

Source

impl BnSpot

Source

impl BnSpot

Source

impl BnSpot

pub async fn subscribe_book_ticker( &self, symbol: &CryptoSymbol, ) -> Result<Receiver<Result<BnBookTickerStream, SharedWsError>>, SharedWsError>

Pushes any update to the best bid or ask’s price or quantity in real-time for a specified symbol. Multiple @bookTicker streams can be subscribed to over one connection.

https://developers.binance.com/docs/binance-spot-api-docs/web-socket-streams#individual-symbol-book-ticker-streams

Source

impl BnSpot

pub fn builder() -> BnSpotBuilder<((),)>

Create a builder for building BnSpot. On the builder, call .executor(...) to set the values of the fields. Finally, call .build() to create the instance of BnSpot.