pub struct BnSpot { /* private fields */ }Implementations
Sourceimpl BnSpot
impl BnSpot
Sourcepub async fn get_account_information(
&self,
) -> BnRestRespType<BnSpotAccountInformation>
pub async fn get_account_information( &self, ) -> BnRestRespType<BnSpotAccountInformation>
Get current account information.
Sourcepub async fn get_account_information_ws(
&self,
) -> BnWsApiRespType<BnSpotAccountInformation>
pub async fn get_account_information_ws( &self, ) -> BnWsApiRespType<BnSpotAccountInformation>
Query information about your account.
Sourceimpl BnSpot
impl BnSpot
Sourcepub async fn ping(&self) -> BnRestRespType<SharedEmpty>
pub async fn ping(&self) -> BnRestRespType<SharedEmpty>
Test connectivity to the Rest API.
Sourcepub async fn ping_ws(&self) -> BnWsApiRespType<SharedEmpty>
pub async fn ping_ws(&self) -> BnWsApiRespType<SharedEmpty>
Test connectivity to the WebSocket API.
Sourcepub async fn get_server_time(&self) -> BnRestRespType<BnServerTime>
pub async fn get_server_time(&self) -> BnRestRespType<BnServerTime>
Test connectivity to the Rest API and get the current server time.
Sourcepub async fn get_server_time_ws(&self) -> BnWsApiRespType<BnServerTime>
pub async fn get_server_time_ws(&self) -> BnWsApiRespType<BnServerTime>
Test connectivity to the WebSocket API and get the current server time.
Sourcepub async fn get_exchange_information(
&self,
) -> BnRestRespType<BnSpotExchangeInformation>
pub async fn get_exchange_information( &self, ) -> BnRestRespType<BnSpotExchangeInformation>
Current exchange trading rules and symbol information
Sourcepub async fn get_exchange_information_ws(
&self,
) -> BnWsApiRespType<BnSpotExchangeInformation>
pub async fn get_exchange_information_ws( &self, ) -> BnWsApiRespType<BnSpotExchangeInformation>
Query current exchange trading rules, rate limits, and symbol information.
Sourceimpl BnSpot
impl BnSpot
Sourcepub async fn get_order_book(
&self,
params: &BnGetOrderBookParams,
) -> BnRestRespType<BnSpotOrderBook>
pub async fn get_order_book( &self, params: &BnGetOrderBookParams, ) -> BnRestRespType<BnSpotOrderBook>
Sourcepub async fn get_order_book_ws(
&self,
params: &BnGetOrderBookParams,
) -> BnWsApiRespType<BnSpotOrderBook>
pub async fn get_order_book_ws( &self, params: &BnGetOrderBookParams, ) -> BnWsApiRespType<BnSpotOrderBook>
Sourceimpl BnSpot
impl BnSpot
Sourcepub async fn subscribe_book_ticker(
&self,
symbol: &CryptoSymbol,
) -> Result<Receiver<Result<BnBookTickerStream, SharedWsError>>, SharedWsError>
pub async fn subscribe_book_ticker( &self, symbol: &CryptoSymbol, ) -> Result<Receiver<Result<BnBookTickerStream, SharedWsError>>, SharedWsError>
Pushes any update to the best bid or ask’s price or quantity in real-time for a specified symbol. Multiple